@@ -1,11 +1,11 @@
 #
 # Configuration file for OAF
 #
-prefix=/gnome
+prefix=/gnome/GNOME1
 exec_prefix=${prefix}
 
-orbit_includes="`/gnome/bin/orbit-config --cflags server`"
-orbit_libs_output="`/gnome/bin/orbit-config --use-service=name --libs server`"
+orbit_includes="`/gnome/GNOME1/bin/orbit-config --cflags server`"
+orbit_libs_output="`/gnome/GNOME1/bin/orbit-config --use-service=name --libs server`"
 
 orbit_libdirs=
 orbit_libs=
@@ -19,5 +19,5 @@ done
 OAF_LIBDIR="-L${exec_prefix}/lib $orbit_libdirs"
 OAF_LIBS="-loaf $orbit_libs"
 OAF_INCLUDEDIR="-I${prefix}/include $orbit_includes"
-MODULE_VERSION="oaf-0.6.6"
+MODULE_VERSION="oaf-0.6.7"
 
